@@ -1,4 +1,4 @@
-/* $Id: libpfkey.h,v 1.8.2.2 2005/04/25 22:00:51 manubsd Exp $ */
+/* $Id: libpfkey.h,v 1.8.2.4 2005/12/04 20:41:47 manubsd Exp $ */
 
 /*
  * Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -44,25 +44,40 @@
 
 struct sadb_msg;
 extern void pfkey_sadump __P((struct sadb_msg *));
+extern void pfkey_sadump_withports __P((struct sadb_msg *));
 extern void pfkey_spdump __P((struct sadb_msg *));
 extern void pfkey_spdump_withports __P((struct sadb_msg *));
 
 struct sockaddr;
 struct sadb_alg;
 
+/* Accomodate different prototypes in <netinet6/ipsec.h> */
+#include <sys/types.h>
+#ifdef HAVE_NETINET6_IPSEC
+#  include <netinet6/ipsec.h>
+#else 
+#  include <netinet/ipsec.h>
+#endif
+
+#ifndef HAVE_IPSEC_POLICY_T
+typedef caddr_t ipsec_policy_t;
+#define __ipsec_const
+#else
+#define __ipsec_const const
+#endif
+
 /* IPsec Library Routines */
 
 int ipsec_check_keylen __P((u_int, u_int, u_int));
 int ipsec_check_keylen2 __P((u_int, u_int, u_int));
 int ipsec_get_keylen __P((u_int, u_int, struct sadb_alg *));
-char *ipsec_dump_policy __P((caddr_t policy, char *delimiter));
-char *ipsec_dump_policy_withports __P((caddr_t policy, char *delimiter));
-void ipsec_hexdump __P((caddr_t buf, int len));
-int  ipsec_get_policylen __P((caddr_t policy));
-caddr_t ipsec_set_policy __P((char *msg, int msglen));
+char *ipsec_dump_policy_withports __P((void *, const char *));
+void ipsec_hexdump __P((const void *, int));
 const char *ipsec_strerror __P((void));
-void kdebug_sadb __P((struct sadb_msg *base));
-
+void kdebug_sadb __P((struct sadb_msg *));
+ipsec_policy_t ipsec_set_policy __P((__ipsec_const char *, int));
+int  ipsec_get_policylen __P((ipsec_policy_t));
+char *ipsec_dump_policy __P((ipsec_policy_t, __ipsec_const char *));
 
 /* PFKey Routines */
 
