@@ -1,4 +1,4 @@
-/* $Id: gssapi.h,v 1.4 2004/06/11 16:00:16 ludvigm Exp $ */
+/* $Id: gssapi.h,v 1.5 2005/02/11 06:59:01 manubsd Exp $ */
 
 /*
  * Copyright 2000 Wasabi Systems, Inc.
@@ -38,7 +38,7 @@
 #include <gssapi/gssapi.h>
 #endif
 
-#define GSSAPI_DEF_NAME         "ike"
+#define GSSAPI_DEF_NAME         "host"
 
 struct ph1handle;
 struct isakmpsa;
@@ -85,4 +85,5 @@ int gssapi_id_sent __P((struct ph1handle *));
 void gssapi_set_id_rcvd __P((struct ph1handle *));
 int gssapi_id_rcvd __P((struct ph1handle *));
 void gssapi_free_state __P((struct ph1handle *));
-vchar_t *gssapi_get_default_id __P((struct ph1handle *));
+vchar_t *gssapi_get_id __P((struct ph1handle *));
+vchar_t *gssapi_get_default_gss_id __P((void));
