@@ -1,4 +1,4 @@
-/* $Id: handler.c,v 1.13.4.3 2005/05/20 00:37:41 manubsd Exp $ */
+/* $Id: handler.c,v 1.13.4.4 2005/07/14 12:00:36 vanhu Exp $ */
 
 /*
  * Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -275,6 +275,11 @@ delph1(iph1)
 	}
 #endif
 
+#ifdef ENABLE_DPD
+	if (iph1->dpd_r_u != NULL)
+		SCHED_KILL(iph1->dpd_r_u);
+#endif
+
 	if (iph1->remote) {
 		racoon_free(iph1->remote);
 		iph1->remote = NULL;
