@@ -1,4 +1,4 @@
-/* $Id: ipsec_doi.c,v 1.26.2.8 2005/05/31 06:05:53 monas Exp $ */
+/* $Id: ipsec_doi.c,v 1.26.2.16 2006/02/02 14:37:17 vanhu Exp $ */
 
 /*
  * Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -92,6 +92,11 @@ static int switch_authmethod(int);
 #ifdef HAVE_GSSAPI
 #include <iconv.h>
 #include "gssapi.h"
+#ifdef HAVE_ICONV_2ND_CONST
+#define __iconv_const const
+#else
+#define __iconv_const
+#endif
 #endif
 
 int verbose_proposal_check = 1;
@@ -737,7 +742,7 @@ t2isakmpsa(trns, sa)
 		{
 			iconv_t cd;
 			size_t srcleft, dstleft, rv;
-			const char *src;
+			__iconv_const char *src;
 			char *dst;
 			int len = ntohs(d->lorv);
 
@@ -775,13 +780,14 @@ t2isakmpsa(trns, sa)
 
 			sa->gssid = vmalloc(len / 2);
 
-			src = (const char *)(d + 1);
+			src = (__iconv_const char *)(d + 1);
 			srcleft = len;
 
 			dst = sa->gssid->v;
 			dstleft = len / 2;
 
-			rv = iconv(cd, &src, &srcleft, &dst, &dstleft);
+			rv = iconv(cd, (__iconv_const char **)&src, &srcleft, 
+				   &dst, &dstleft);
 			if (rv != 0) {
 				if (rv == -1) {
 					plog(LLV_ERROR, LOCATION, NULL,
@@ -1929,6 +1935,9 @@ check_trns_ah(t_id)
 	switch (t_id) {
 	case IPSECDOI_AH_MD5:
 	case IPSECDOI_AH_SHA:
+	case IPSECDOI_AH_SHA256:
+	case IPSECDOI_AH_SHA384:
+	case IPSECDOI_AH_SHA512:
 		return 0;
 	case IPSECDOI_AH_DES:
 		plog(LLV_ERROR, LOCATION, NULL,
@@ -2282,6 +2291,24 @@ ahmismatch:
 						goto ahmismatch;
 				}
 				break;
+ 			case IPSECDOI_ATTR_AUTH_HMAC_SHA2_256:
+ 				if (proto_id == IPSECDOI_PROTO_IPSEC_AH) {
+ 					if (trns->t_id != IPSECDOI_AH_SHA256)
+ 						goto ahmismatch;
+ 				}	
+ 				break;
+ 			case IPSECDOI_ATTR_AUTH_HMAC_SHA2_384:
+ 				if (proto_id == IPSECDOI_PROTO_IPSEC_AH) {
+ 					if (trns->t_id != IPSECDOI_AH_SHA384)
+ 						goto ahmismatch;
+ 				}
+ 				break;
+ 			case IPSECDOI_ATTR_AUTH_HMAC_SHA2_512:
+ 				if (proto_id == IPSECDOI_PROTO_IPSEC_AH) {
+ 					if (trns->t_id != IPSECDOI_AH_SHA512)
+ 					goto ahmismatch;
+ 				}
+ 				break;
 			case IPSECDOI_ATTR_AUTH_DES_MAC:
 			case IPSECDOI_ATTR_AUTH_KPDK:
 				plog(LLV_ERROR, LOCATION, NULL,
@@ -2803,8 +2830,8 @@ setph1attr(sa, buf)
 					goto gssid_done;
 				}
 				odst = dst;
-				rv = iconv(cd, &src, &srcleft,
-				    &dst, &dstleft);
+				rv = iconv(cd, (__iconv_const char **)&src, 
+				    &srcleft, &dst, &dstleft);
 				if (rv != 0) {
 					if (rv == -1) {
 						plog(LLV_ERROR, LOCATION, NULL,
@@ -3534,12 +3561,23 @@ set_identifier(vpp, type, value)
 	vchar_t *new = NULL;
 
 	/* simply return if value is null. */
-	if (!value)
+	if (!value){
+		if( type == IDTYPE_FQDN || type == IDTYPE_USERFQDN){
+			plog(LLV_ERROR, LOCATION, NULL,
+				 "No %s\n", type == IDTYPE_FQDN ? "fqdn":"user fqdn");
+			return -1;
+		}
 		return 0;
+	}
 
 	switch (type) {
 	case IDTYPE_FQDN:
 	case IDTYPE_USERFQDN:
+		if(value->l <= 1){
+			plog(LLV_ERROR, LOCATION, NULL,
+				 "Empty %s\n", type == IDTYPE_FQDN ? "fqdn":"user fqdn");
+			return -1;
+		}
 #ifdef ENABLE_HYBRID
 	case IDTYPE_LOGIN:
 #endif
@@ -3612,7 +3650,7 @@ set_identifier(vpp, type, value)
 			size_t len;
 			char save;
 
-			xn = d2i_X509_NAME(NULL, &ptr, new->l);
+			xn = d2i_X509_NAME(NULL, (void *)&ptr, new->l);
 			bio = BIO_new(BIO_s_mem());
 			
 			X509_NAME_print_ex(bio, xn, 0, 0);
@@ -3704,7 +3742,13 @@ ipsecdoi_sockaddr2id(saddr, prefixlen, ul_proto)
 	switch (saddr->sa_family) {
 	case AF_INET:
 		len1 = sizeof(struct in_addr);
-		if (prefixlen == (sizeof(struct in_addr) << 3)) {
+		if (
+#if 0
+			prefixlen == ~0
+#else
+			prefixlen == (sizeof(struct in_addr) << 3)
+#endif
+			) {
 			type = IPSECDOI_ID_IPV4_ADDR;
 			len2 = 0;
 		} else {
@@ -3717,7 +3761,7 @@ ipsecdoi_sockaddr2id(saddr, prefixlen, ul_proto)
 #ifdef INET6
 	case AF_INET6:
 		len1 = sizeof(struct in6_addr);
-		if (prefixlen == (sizeof(struct in6_addr) << 3)) {
+		if (prefixlen == ~0) {
 			type = IPSECDOI_ID_IPV6_ADDR;
 			len2 = 0;
 		} else {
@@ -4141,6 +4185,12 @@ ipsecdoi_authalg2trnsid(alg)
 		return IPSECDOI_AH_MD5;
         case IPSECDOI_ATTR_AUTH_HMAC_SHA1:
 		return IPSECDOI_AH_SHA;
+	case IPSECDOI_ATTR_AUTH_HMAC_SHA2_256:
+		return IPSECDOI_AH_SHA256;
+	case IPSECDOI_ATTR_AUTH_HMAC_SHA2_384:
+		return IPSECDOI_AH_SHA384;
+	case IPSECDOI_ATTR_AUTH_HMAC_SHA2_512:
+		return IPSECDOI_AH_SHA512;
         case IPSECDOI_ATTR_AUTH_DES_MAC:
 		return IPSECDOI_AH_DES;
 	case IPSECDOI_ATTR_AUTH_KPDK:
