@@ -97,7 +97,7 @@ base_i1send(iph1, msg)
 	struct payload_list *plist = NULL;
 	int error = -1;
 #ifdef ENABLE_NATT
-	vchar_t *vid_natt[MAX_NATT_VID_COUNT];
+	vchar_t *vid_natt[MAX_NATT_VID_COUNT] = { NULL };
 	int i, vid_natt_i = 0;
 #endif
 #ifdef ENABLE_FRAG
@@ -425,6 +425,11 @@ base_i2send(iph1, msg)
 	case OAKLEY_ATTR_AUTH_METHOD_RSAENC:
 	case OAKLEY_ATTR_AUTH_METHOD_RSAREV:
 		break;
+	default:
+		plog(LLV_ERROR, LOCATION, NULL, "invalid authmethod %d\n",
+			iph1->approval->authmethod);
+		goto end;
+		break;
 	}
 
 #ifdef ENABLE_NATT
@@ -1124,6 +1129,11 @@ base_r2send(iph1, msg)
 	case OAKLEY_ATTR_AUTH_METHOD_RSAENC:
 	case OAKLEY_ATTR_AUTH_METHOD_RSAREV:
 		break;
+	default:
+		plog(LLV_ERROR, LOCATION, NULL, "invalid authmethod %d\n",
+			iph1->approval->authmethod);
+		goto end;
+		break;
 	}
 
 #ifdef ENABLE_NATT
