@@ -1,4 +1,4 @@
-/* $Id: isakmp_xauth.c,v 1.17.2.5 2005/05/20 07:31:09 manubsd Exp $ */
+/* $Id: isakmp_xauth.c,v 1.17.2.7 2006/06/12 18:06:01 manubsd Exp $ */
 
 /*
  * Copyright (C) 2004-2005 Emmanuel Dreyfus
@@ -611,7 +611,7 @@ xauth_login_pam(port, raddr, usr, pwd)
 	const void *data;
 	size_t len;
 	int type;
-	char *remote;
+	char *remote = NULL;
 	pam_handle_t *pam = NULL;
 
 	if (isakmp_cfg_config.port_pool == NULL) {
@@ -674,11 +674,16 @@ xauth_login_pam(port, raddr, usr, pwd)
 		goto out;
 	}
 
+	if (remote != NULL)
+		free(remote);
+
 	return 0;
 
 out:
 	pam_end(pam, error);
 	isakmp_cfg_config.port_pool[port].pam = NULL;
+	if (remote != NULL)
+		free(remote);
 	return -1;
 }
 #endif
