@@ -49,6 +49,8 @@
 
 #include "localconf.h"
 #include "algorithm.h"
+#include "admin.h"
+#include "privsep.h"
 #include "isakmp_var.h"
 #include "isakmp.h"
 #include "ipsec_doi.h"
@@ -62,7 +64,6 @@
 struct localconf *lcconf;
 
 static void setdefault __P((void));
-static vchar_t *getpsk __P((const char *, const int));
 
 void
 initlcconf()
@@ -99,6 +100,9 @@ flushlcconf()
 static void
 setdefault()
 {
+	lcconf->uid = 0;
+	lcconf->gid = 0;
+	lcconf->chroot = NULL;
 	lcconf->autograbaddr = 1;
 	lcconf->port_isakmp = PORT_ISAKMP;
 	lcconf->port_isakmp_natt = PORT_ISAKMP_NATT;
@@ -116,6 +120,7 @@ setdefault()
 	lcconf->wait_ph2complete = LC_DEFAULT_WAIT_PH2COMPLETE;
 	lcconf->strict_address = FALSE;
 	lcconf->complex_bundle = TRUE; /*XXX FALSE;*/
+	lcconf->gss_id_enc = LC_GSSENC_UTF16LE; /* Windows compatibility */
 	lcconf->natt_ka_interval = LC_DEFAULT_NATT_KA_INTERVAL;
 }
 
@@ -139,7 +144,7 @@ getpskbyname(id0)
 		id0->l - sizeof(struct ipsecdoi_id_b));
 	id[id0->l - sizeof(struct ipsecdoi_id_b)] = '\0';
 
-	key = getpsk(id, id0->l - sizeof(struct ipsecdoi_id_b));
+	key = privsep_getpsk(id, id0->l - sizeof(struct ipsecdoi_id_b));
 
 end:
 	if (id)
@@ -159,12 +164,12 @@ getpskbyaddr(remote)
 
 	GETNAMEINFO(remote, addr, port);
 
-	key = getpsk(addr, strlen(addr));
+	key = privsep_getpsk(addr, strlen(addr));
 
 	return key;
 }
 
-static vchar_t *
+vchar_t *
 getpsk(str, len)
 	const char *str;
 	const int len;
