@@ -1,4 +1,4 @@
-/* $Id: misc.h,v 1.6 2004/06/11 16:00:17 ludvigm Exp $ */
+/* $Id: misc.h,v 1.6.10.1 2005/11/06 17:18:26 monas Exp $ */
 
 /*
  * Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -52,6 +52,10 @@ extern double timedelta __P((struct timeval *, struct timeval *));
 #define strlcpy(d,s,l) (strncpy(d,s,l), (d)[(l)-1] = '\0')
 #endif
 
+#ifndef HAVE_STRLCAT
+#define strlcat(d,s,l) strncat(d,s,(l)-strlen(d)-1)
+#endif
+
 #include "libpfkey.h"
 
 #endif /* _MISC_H */
