@@ -290,7 +290,7 @@ natt_float_ports (struct ph1handle *iph1)
 	
 	set_port (iph1->local, iph1->natt_options->float_port);
 	set_port (iph1->remote, iph1->natt_options->float_port);
-	iph1->natt_flags |= NAT_PORTS_CHANGED;
+	iph1->natt_flags |= NAT_PORTS_CHANGED | NAT_ADD_NON_ESP_MARKER;
 	
 	natt_keepalive_add_ph1 (iph1);
 }
@@ -391,7 +391,7 @@ natt_keepalive_add_ph1 (struct ph1handle *iph1)
   /* Should only the NATed host send keepalives?
      If yes, add '(iph1->natt_flags & NAT_DETECTED_ME)'
      to the following condition. */
-  if (iph1->natt_flags & NAT_PORTS_CHANGED &&
+  if (iph1->natt_flags & NAT_DETECTED &&
       ! (iph1->natt_flags & NAT_KA_QUEUED)) {
     ret = natt_keepalive_add (iph1->local, iph1->remote);
     if (ret == 0)
