@@ -38,13 +38,14 @@
 #define	NAT_DETECTED_PEER	(1L<<2)
 #define	NAT_PORTS_CHANGED	(1L<<3)
 #define	NAT_KA_QUEUED		(1L<<4)
+#define	NAT_ADD_NON_ESP_MARKER	(1L<<5)
 
 #define	NATT_AVAILABLE(ph1)	((iph1)->natt_flags & NAT_ANNOUNCED)
 
 #define	NAT_DETECTED	(NAT_DETECTED_ME | NAT_DETECTED_PEER)
 
 #define	NON_ESP_MARKER_LEN	sizeof(u_int32_t)
-#define	NON_ESP_MARKER_USE(iph1)	(((iph1)->natt_flags & NAT_PORTS_CHANGED) / NAT_PORTS_CHANGED)
+#define	NON_ESP_MARKER_USE(iph1)	((iph1)->natt_flags & NAT_ADD_NON_ESP_MARKER)
 
 /* These are the values from parsing "remote {}" 
    block of the config file. */
@@ -68,6 +69,7 @@ struct ph2natt {
   u_int16_t	sport;
   u_int16_t	dport;
   struct sockaddr	*oa;
+  u_int16_t	frag;
 };
 
 int natt_vendorid (int vid);
