@@ -1,4 +1,4 @@
-/* $Id: proposal.c,v 1.13.8.3 2005/05/20 01:16:00 manubsd Exp $ */
+/* $Id: proposal.c,v 1.13.8.5 2005/07/28 05:05:52 manubsd Exp $ */
 
 /*
  * Copyright (C) 1995, 1996, 1997, and 1998 WIDE Project.
@@ -1025,12 +1025,15 @@ set_proposal_from_policy(iph2, sp_main, sp_sub)
 		}
 
 		newpr->proto_id = ipproto2doi(req->saidx.proto);
-		newpr->spisize = 4;
+		if (newpr->proto_id == IPSECDOI_PROTO_IPCOMP)
+			newpr->spisize = 2;
+		else
+			newpr->spisize = 4;
 		if (lcconf->complex_bundle) {
 			newpr->encmode = pfkey2ipsecdoi_mode(req->saidx.mode);
 #ifdef ENABLE_NATT
 			if (iph2->ph1 && (iph2->ph1->natt_flags & NAT_DETECTED))
-				encmodesv += iph2->ph1->natt_options->mode_udp_diff;
+				newpr->encmode += iph2->ph1->natt_options->mode_udp_diff;
 #endif
 		}
 		else
